@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertBlock;
 
 our $DATE = '2015-03-11'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -77,7 +77,7 @@ Dist::Zilla::Plugin::InsertBlock - Insert a block of text from another file
 
 =head1 VERSION
 
-This document describes version 0.01 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-03-11.
+This document describes version 0.02 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-03-11.
 
 =head1 SYNOPSIS
 
@@ -91,13 +91,13 @@ In lib/Foo/Base.pm:
 
  =head1 ATTRIBUTES
 
- =for BEGIN_BLOCK: attributes
+ =for BEGIN_BLOCK: base_attributes
 
  =head2 attr1
 
  =head2 attr2
 
- =for END_BLOCK: attributes
+ =for END_BLOCK: base_attributes
 
  ...
 
@@ -107,7 +107,7 @@ In lib/Foo/Bar.pm:
 
  =head1 ATTRIBUTES
 
- # INSERT_BLOCK: lib/Foo/Bar.pm attributes
+ # INSERT_BLOCK: lib/Foo/Bar.pm base_attributes
 
  =head2 attr3
 
@@ -115,15 +115,17 @@ In lib/Foo/Bar.pm:
 
 =head1 DESCRIPTION
 
-This plugin finds C<<# INSERT_BLOCK: <file> <name> >> directive in your
+This plugin finds C<< # INSERT_BLOCK: <file> <name> >> directive in your
 POD/code, find the block of text named I<name> in I<file>, and inserts the block
 of text to replace the directive.
 
-Block of code is enclosed using either this syntax:
+Block is marked/defined using either this syntax:
+
+ =for BEGIN_BLOCK: Name
 
- # BEGIN_BLOCK: Name
  ...
- # END_BLOCK: Name
+
+ =for END_BLOCK: Name
 
 or this syntax:
 
@@ -131,7 +133,7 @@ or this syntax:
  ...
  # END_BLOCK: Name
 
-Name is case-sensitive.
+Block name is case-sensitive.
 
 This plugin can be useful to avoid repetition/manual copy-paste, e.g. you want
 to list POD attributes, methods, etc from a base class into a subclass.
